@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2020 Arm Limited.
+ * Copyright (c) 2018-2021, 2023 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -27,7 +27,12 @@
 #include "arm_compute/core/Error.h"
 #include "arm_compute/core/PixelValue.h"
 #include "arm_compute/core/Types.h"
+#include "arm_compute/function_info/ActivationLayerInfo.h"
+#include "arm_compute/function_info/ConvolutionInfo.h"
+#include "arm_compute/function_info/FullyConnectedLayerInfo.h"
+#include "arm_compute/function_info/GEMMInfo.h"
 #include "arm_compute/runtime/CL/CLTunerTypes.h"
+#include "arm_compute/runtime/CL/CLTypes.h"
 
 #include <limits>
 #include <string>
@@ -37,6 +42,7 @@ namespace arm_compute
 namespace graph
 {
 using arm_compute::CLTunerMode;
+using arm_compute::CLBackendType;
 using arm_compute::Status;
 
 using arm_compute::Coordinates;
@@ -60,6 +66,7 @@ using arm_compute::PoolingType;
 using arm_compute::PriorBoxLayerInfo;
 using arm_compute::DimensionRoundingType;
 using arm_compute::InterpolationPolicy;
+using arm_compute::experimental::PostOpType;
 
 using GraphID    = unsigned int;
 using TensorID   = unsigned int;
@@ -76,26 +83,30 @@ constexpr EdgeID EmptyEdgeID = std::numeric_limits<EdgeID>::max();
 
 // Forward declarations
 struct TensorDescriptor;
+
 /** Graph configuration structure */
 struct GraphConfig
 {
-    bool        use_function_memory_manager{ true };   /**< Use a memory manager to manage per-function auxilary memory */
-    bool        use_function_weights_manager{ true };  /**< Use a weights manager to manage transformed weights */
-    bool        use_transition_memory_manager{ true }; /**< Use a memory manager to manager transition buffer memory */
-    bool        use_tuner{ false };                    /**< Use a tuner in tunable backends */
-    bool        convert_to_uint8{ false };             /**< Convert graph to a synthetic uint8 graph */
-    CLTunerMode tuner_mode{ CLTunerMode::EXHAUSTIVE }; /**< Tuner mode to be used by the CL tuner */
-    int         num_threads{ -1 };                     /**< Number of threads to use (thread capable backends), if 0 the backend will auto-initialize, if -1 the backend will stay as it is. */
-    std::string tuner_file{ "acl_tuner.csv" };         /**< File to load/store tuning values from */
+    bool          use_function_memory_manager{ true };   /**< Use a memory manager to manage per-function auxilary memory */
+    bool          use_function_weights_manager{ true };  /**< Use a weights manager to manage transformed weights */
+    bool          use_transition_memory_manager{ true }; /**< Use a memory manager to manager transition buffer memory */
+    bool          use_tuner{ false };                    /**< Use a tuner in tunable backends */
+    bool          use_synthetic_type{ false };           /**< Convert graph to a synthetic graph for a data type */
+    DataType      synthetic_type{ DataType::QASYMM8 };   /**< The data type of the synthetic graph  */
+    CLTunerMode   tuner_mode{ CLTunerMode::EXHAUSTIVE }; /**< Tuner mode to be used by the CL tuner */
+    int           num_threads{ -1 };                     /**< Number of threads to use (thread capable backends), if 0 the backend will auto-initialize, if -1 the backend will stay as it is. */
+    std::string   tuner_file{ "acl_tuner.csv" };         /**< File to load/store tuning values from */
+    std::string   mlgo_file{ "heuristics.mlgo" };        /**< Filename to load MLGO heuristics from */
+    CLBackendType backend_type{ CLBackendType::Native }; /**< CL backend type to use */
 };
 
 /**< Device target types */
 enum class Target
 {
     UNSPECIFIED, /**< Unspecified Target */
-    NEON,        /**< NEON capable target device */
+    NEON,        /**< Arm® Neon™ capable target device */
     CL,          /**< OpenCL capable target device */
-    GC,          /**< GLES compute capable target device */
+    CLVK,        /**< CLVK capable target device */
 };
 
 /** Supported Element-wise operations */
@@ -104,6 +115,9 @@ enum class EltwiseOperation
     Add, /**< Arithmetic addition */
     Sub, /**< Arithmetic subtraction */
     Mul, /**< Arithmetic multiplication */
+    Max, /**< Arithmetic maximum */
+    Div, /**< Arithmetic division */
+    Min, /**< Arithmetic minimum */
 };
 
 /** Supported Unary Element-wise operations */
@@ -136,16 +150,67 @@ enum class FastMathHint
     Disabled, /**< Fast math disabled for Convolution layer */
 };
 
+/** Convolution post operator info */
+class ConvPostOpInfo
+{
+public:
+    /** Returns post op type
+     *
+     * @return Post op type
+     */
+    virtual PostOpType type() const = 0;
+    virtual ~ConvPostOpInfo()
+    {
+    }
+};
+
+class ConvPostOpInfoActivation : public ConvPostOpInfo
+{
+public:
+    ConvPostOpInfoActivation(const ActivationLayerInfo &act)
+        : _act(act)
+    {
+    }
+    ~ConvPostOpInfoActivation() override
+    {
+    }
+    PostOpType type() const override
+    {
+        return PostOpType::Activation;
+    }
+    ActivationLayerInfo _act;
+};
+
+class ConvPostOpInfoEltwiseAdd : public ConvPostOpInfo
+{
+public:
+    ConvPostOpInfoEltwiseAdd(int arg_pos, const ConvertPolicy &policy)
+        : _prev_op_dst_pos(arg_pos), _policy(policy)
+    {
+    }
+    PostOpType type() const override
+    {
+        return PostOpType::Eltwise_Add;
+    }
+    ~ConvPostOpInfoEltwiseAdd() override
+    {
+    }
+    int           _prev_op_dst_pos;
+    ConvertPolicy _policy;
+};
+
 /** Supported nodes */
 enum class NodeType
 {
     ActivationLayer,
+    ArgMinMaxLayer,
     BatchNormalizationLayer,
     BoundingBoxTransformLayer,
     ChannelShuffleLayer,
     ConcatenateLayer,
     ConvolutionLayer,
     DeconvolutionLayer,
+    DepthToSpaceLayer,
     DepthwiseConvolutionLayer,
     DequantizationLayer,
     DetectionOutputLayer,
@@ -154,8 +219,11 @@ enum class NodeType
     FlattenLayer,
     FullyConnectedLayer,
     FusedConvolutionBatchNormalizationLayer,
+    FusedConvolutionWithPostOp,
+    FusedConvolutionBatchNormalizationLayerWithPostOpsLayer,
     FusedDepthwiseConvolutionBatchNormalizationLayer,
     GenerateProposalsLayer,
+    L2NormalizeLayer,
     NormalizationLayer,
     NormalizePlanarYUVLayer,
     PadLayer,
@@ -165,6 +233,7 @@ enum class NodeType
     PrintLayer,
     PriorBoxLayer,
     QuantizationLayer,
+    ReductionOperationLayer,
     ReorgLayer,
     ReshapeLayer,
     ResizeLayer,
@@ -173,9 +242,9 @@ enum class NodeType
     SliceLayer,
     SplitLayer,
     StackLayer,
+    StridedSliceLayer,
     UpsampleLayer,
     UnaryEltwiseLayer,
-    YOLOLayer,
 
     Input,
     Output,
