@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2020 Arm Limited.
+ * Copyright (c) 2019-2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -208,10 +208,12 @@ public:
 
         // Finalize graph
         GraphConfig config;
-        config.num_threads      = common_params.threads;
-        config.use_tuner        = common_params.enable_tuner;
-        config.tuner_file       = common_params.tuner_file;
-        config.convert_to_uint8 = (common_params.data_type == DataType::QASYMM8);
+        config.num_threads        = common_params.threads;
+        config.use_tuner          = common_params.enable_tuner;
+        config.tuner_file         = common_params.tuner_file;
+        config.mlgo_file          = common_params.mlgo_file;
+        config.use_synthetic_type = arm_compute::is_data_type_quantized(common_params.data_type);
+        config.synthetic_type     = common_params.data_type;
 
         graph.finalize(common_params.target, config);
 
