@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2020 Arm Limited.
+ * Copyright (c) 2017-2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -63,11 +63,11 @@ public:
 
         // Create a preprocessor object
         const std::array<float, 3> mean_rgb{ { 122.68f, 116.67f, 104.01f } };
-        std::unique_ptr<IPreprocessor> preprocessor = arm_compute::support::cpp14::make_unique<CaffePreproccessor>(mean_rgb);
+        std::unique_ptr<IPreprocessor> preprocessor = std::make_unique<CaffePreproccessor>(mean_rgb);
 
         // Create input descriptor
         const auto        operation_layout = common_params.data_layout;
-        const TensorShape tensor_shape     = permute_shape(TensorShape(224U, 224U, 3U, 1U), DataLayout::NCHW, operation_layout);
+        const TensorShape tensor_shape     = permute_shape(TensorShape(224U, 224U, 3U, common_params.batches), DataLayout::NCHW, operation_layout);
         TensorDescriptor  input_descriptor = TensorDescriptor(tensor_shape, common_params.data_type).set_layout(operation_layout);
 
         // Set weights trained layout
@@ -164,11 +164,13 @@ public:
 
         // Finalize graph
         GraphConfig config;
-        config.num_threads      = common_params.threads;
-        config.use_tuner        = common_params.enable_tuner;
-        config.tuner_mode       = common_params.tuner_mode;
-        config.tuner_file       = common_params.tuner_file;
-        config.convert_to_uint8 = (common_params.data_type == DataType::QASYMM8);
+        config.num_threads        = common_params.threads;
+        config.use_tuner          = common_params.enable_tuner;
+        config.tuner_mode         = common_params.tuner_mode;
+        config.tuner_file         = common_params.tuner_file;
+        config.mlgo_file          = common_params.mlgo_file;
+        config.use_synthetic_type = arm_compute::is_data_type_quantized(common_params.data_type);
+        config.synthetic_type     = common_params.data_type;
 
         graph.finalize(common_params.target, config);
 
