@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2020 Arm Limited.
+ * Copyright (c) 2017-2023 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -29,8 +29,10 @@
 
 #include "arm_compute/core/Error.h"
 
+#include <algorithm>
 #include <dlfcn.h>
 #include <iostream>
+#include <sstream>
 
 namespace arm_compute
 {
@@ -50,7 +52,7 @@ CLSymbols &CLSymbols::get()
 
 bool CLSymbols::load_default()
 {
-    static const std::vector<std::string> libraries{ "libOpenCL.so", "libGLES_mali.so", "libmali.so" };
+    static const std::vector<std::string> libraries_filenames{ "libOpenCL.so", "libGLES_mali.so", "libmali.so" };
 
     if(_loaded.first)
     {
@@ -60,37 +62,85 @@ bool CLSymbols::load_default()
     // Indicate that default loading has been tried
     _loaded.first = true;
 
-    for(const auto &lib : libraries)
+    if(load(libraries_filenames, /* use_loader */ false))
     {
-        if(load(lib))
-        {
-            ARM_COMPUTE_ERROR_ON_MSG(this->clBuildProgram_ptr == nullptr, "Failed to load OpenCL symbols from shared library");
-            return true;
-        }
+        ARM_COMPUTE_ERROR_ON_MSG(this->clBuildProgram_ptr == nullptr, "Failed to load OpenCL symbols from shared library");
+        return true;
     }
 
-    std::cerr << "Couldn't find any OpenCL library.\n";
+#ifdef __ANDROID__
+    // When running in NDK environment, the above libraries are not accessible.
+    static const std::vector<std::string> android_libraries_filenames{ "libOpenCL-pixel.so", "libOpenCL-car.so" };
+
+    if(load(android_libraries_filenames, /* use_loader */ true))
+    {
+        ARM_COMPUTE_ERROR_ON_MSG(this->clBuildProgram_ptr == nullptr, "Failed to load OpenCL symbols from android shared library");
+        return true;
+    }
+#endif // __ANDROID__
+
+    // If not returned till here then libraries not found
+    std::stringstream ss;
+    std::for_each(libraries_filenames.begin(), libraries_filenames.end(), [&ss](const std::string & s)
+    {
+        ss << s << " ";
+    });
+#ifdef __ANDROID__
+    std::for_each(android_libraries_filenames.begin(), android_libraries_filenames.end(), [&ss](const std::string & s)
+    {
+        ss << s << " ";
+    });
+#endif // __ANDROID__
+    std::cerr << "Couldn't find any of the following OpenCL library: " << ss.str() << std::endl;
     return false;
 }
 
-bool CLSymbols::load(const std::string &library)
+bool CLSymbols::load(const std::vector<std::string> &libraries_filenames, bool use_loader)
 {
-    void *handle = dlopen(library.c_str(), RTLD_LAZY | RTLD_LOCAL);
-
-    if(handle == nullptr)
+    void        *handle = nullptr;
+    unsigned int index  = 0;
+    for(index = 0; index < libraries_filenames.size(); ++index)
+    {
+        handle = dlopen(libraries_filenames[index].c_str(), RTLD_LAZY | RTLD_LOCAL);
+        if(handle != nullptr)
+        {
+            break;
+        }
+    }
+    if(index == libraries_filenames.size())
     {
-        std::cerr << "Can't load " << library << ": " << dlerror() << "\n";
         // Set status of loading to failed
         _loaded.second = false;
         return false;
     }
 
+#ifdef __ANDROID__
+    typedef void* (*loadOpenCLPointer_t)(const char* name);
+    loadOpenCLPointer_t loadOpenCLPointer;
+    if (use_loader) {
+        typedef void (*enableOpenCL_t)();
+        enableOpenCL_t enableOpenCL =
+            reinterpret_cast<enableOpenCL_t>(dlsym(handle, "enableOpenCL"));
+        enableOpenCL();
+
+        loadOpenCLPointer = reinterpret_cast<loadOpenCLPointer_t>(
+            dlsym(handle, "loadOpenCLPointer"));
+    } else {
+        loadOpenCLPointer = nullptr;
+    }
+#define LOAD_FUNCTION_PTR(func_name, _handle) \
+    func_name##_ptr = reinterpret_cast<decltype(func_name) *>( use_loader ? \
+        loadOpenCLPointer(#func_name) : dlsym(handle, #func_name));
+#else /* __ANDROID__ */
+    (void)use_loader; // Avoid unused warning
 #define LOAD_FUNCTION_PTR(func_name, handle) \
     func_name##_ptr = reinterpret_cast<decltype(func_name) *>(dlsym(handle, #func_name));
+#endif /* __ANDROID__ */
 
     LOAD_FUNCTION_PTR(clCreateContext, handle);
     LOAD_FUNCTION_PTR(clCreateContextFromType, handle);
     LOAD_FUNCTION_PTR(clCreateCommandQueue, handle);
+    LOAD_FUNCTION_PTR(clCreateCommandQueueWithProperties, handle);
     LOAD_FUNCTION_PTR(clGetContextInfo, handle);
     LOAD_FUNCTION_PTR(clBuildProgram, handle);
     LOAD_FUNCTION_PTR(clEnqueueNDRangeKernel, handle);
@@ -122,6 +172,7 @@ bool CLSymbols::load(const std::string &library)
     LOAD_FUNCTION_PTR(clGetDeviceIDs, handle);
     LOAD_FUNCTION_PTR(clGetMemObjectInfo, handle);
     LOAD_FUNCTION_PTR(clRetainEvent, handle);
+    LOAD_FUNCTION_PTR(clGetPlatformInfo, handle);
     LOAD_FUNCTION_PTR(clGetPlatformIDs, handle);
     LOAD_FUNCTION_PTR(clGetKernelWorkGroupInfo, handle);
     LOAD_FUNCTION_PTR(clGetCommandQueueInfo, handle);
@@ -134,6 +185,7 @@ bool CLSymbols::load(const std::string &library)
     LOAD_FUNCTION_PTR(clEnqueueMarker, handle);
     LOAD_FUNCTION_PTR(clWaitForEvents, handle);
     LOAD_FUNCTION_PTR(clCreateImage, handle);
+    LOAD_FUNCTION_PTR(clSetKernelExecInfo, handle);
 
     // Third-party extensions
     LOAD_FUNCTION_PTR(clImportMemoryARM, handle);
@@ -151,6 +203,23 @@ bool CLSymbols::load(const std::string &library)
 bool opencl_is_available()
 {
     CLSymbols::get().load_default();
+
+    // Using static objects that rely on OpenCL in their constructor or
+    // destructor is implementation defined according to the OpenCL API
+    // Specification. These objects include CLScheduler.
+    //
+    // For compatibility with OpenCL runtimes that also use static objects to
+    // hold their state, we call a harmless OpenCL function (clGetPlatformIDs
+    // with invalid parameters must result in CL_INVALID_VALUE) to ensure the
+    // runtimes have a chance to initialize their static objects first. Thanks
+    // to C++11 rules about normal program completion (cf [basic.start]), this
+    // ensures their static objects are destroyed last, i.e. after the
+    // singleton CLScheduler is destroyed.
+    //
+    // When OpenCL is not available, this call results in CL_OUT_OF_RESOURCES,
+    // which is equally harmless.
+    (void)clGetPlatformIDs(0, nullptr, nullptr);
+
     return CLSymbols::get().clBuildProgram_ptr != nullptr;
 }
 } // namespace arm_compute
@@ -274,6 +343,23 @@ cl_command_queue clCreateCommandQueue(cl_context                  context,
     }
 }
 
+cl_command_queue clCreateCommandQueueWithProperties(cl_context                 context,
+                                                    cl_device_id               device,
+                                                    const cl_queue_properties *properties,
+                                                    cl_int                    *errcode_ret)
+{
+    arm_compute::CLSymbols::get().load_default();
+    auto func = arm_compute::CLSymbols::get().clCreateCommandQueueWithProperties_ptr;
+    if(func != nullptr)
+    {
+        return func(context, device, properties, errcode_ret);
+    }
+    else
+    {
+        return nullptr;
+    }
+}
+
 cl_context clCreateContext(
     const cl_context_properties *properties,
     cl_uint                      num_devices,
@@ -847,6 +933,24 @@ cl_int clRetainEvent(cl_event event)
     }
 }
 
+cl_int clGetPlatformInfo(cl_platform_id   platform,
+                         cl_platform_info param_name,
+                         size_t           param_value_size,
+                         void            *param_value,
+                         size_t          *param_value_size_ret)
+{
+    arm_compute::CLSymbols::get().load_default();
+    auto func = arm_compute::CLSymbols::get().clGetPlatformInfo_ptr;
+    if(func != nullptr)
+    {
+        return func(platform, param_name, param_value_size, param_value, param_value_size_ret);
+    }
+    else
+    {
+        return CL_OUT_OF_RESOURCES;
+    }
+}
+
 cl_int clGetPlatformIDs(cl_uint num_entries, cl_platform_id *platforms, cl_uint *num_platforms)
 {
     arm_compute::CLSymbols::get().load_default();
@@ -962,6 +1066,23 @@ clCreateImage(cl_context             context,
     }
 }
 
+cl_int clSetKernelExecInfo(cl_kernel           kernel,
+                           cl_kernel_exec_info param_name,
+                           size_t              param_value_size,
+                           const void         *param_value)
+{
+    arm_compute::CLSymbols::get().load_default();
+    auto func = arm_compute::CLSymbols::get().clSetKernelExecInfo_ptr;
+    if(func != nullptr)
+    {
+        return func(kernel, param_name, param_value_size, param_value);
+    }
+    else
+    {
+        return CL_OUT_OF_RESOURCES;
+    }
+}
+
 cl_mem
 clImportMemoryARM(cl_context                      context,
                   cl_mem_flags                    flags,
