@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2020 Arm Limited.
+ * Copyright (c) 2019-2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -23,8 +23,9 @@
  */
 #include "arm_compute/runtime/CL/functions/CLDepthToSpaceLayer.h"
 
-#include "arm_compute/core/CL/kernels/CLDepthToSpaceLayerKernel.h"
-#include "support/MemorySupport.h"
+#include "src/core/CL/kernels/CLDepthToSpaceLayerKernel.h"
+
+#include "src/common/utils/Log.h"
 
 #include <utility>
 
@@ -37,7 +38,8 @@ void CLDepthToSpaceLayer::configure(const ICLTensor *input, ICLTensor *output, i
 
 void CLDepthToSpaceLayer::configure(const CLCompileContext &compile_context, const ICLTensor *input, ICLTensor *output, int32_t block_shape)
 {
-    auto k = arm_compute::support::cpp14::make_unique<CLDepthToSpaceLayerKernel>();
+    ARM_COMPUTE_LOG_PARAMS(input, output, block_shape);
+    auto k = std::make_unique<CLDepthToSpaceLayerKernel>();
     k->configure(compile_context, input, output, block_shape);
     _kernel = std::move(k);
 }
