@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2020 Arm Limited.
+ * Copyright (c) 2018-2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,11 +24,12 @@
 #include "arm_compute/runtime/CL/functions/CLReorgLayer.h"
 
 #include "arm_compute/core/CL/ICLTensor.h"
-#include "arm_compute/core/CL/kernels/CLReorgLayerKernel.h"
 #include "arm_compute/core/Error.h"
 #include "arm_compute/core/TensorInfo.h"
 #include "arm_compute/core/Validate.h"
-#include "support/MemorySupport.h"
+#include "src/core/CL/kernels/CLReorgLayerKernel.h"
+
+#include "src/common/utils/Log.h"
 
 #include <utility>
 
@@ -41,7 +42,8 @@ void CLReorgLayer::configure(ICLTensor *input, ICLTensor *output, int32_t stride
 
 void CLReorgLayer::configure(const CLCompileContext &compile_context, ICLTensor *input, ICLTensor *output, int32_t stride)
 {
-    auto k = arm_compute::support::cpp14::make_unique<CLReorgLayerKernel>();
+    ARM_COMPUTE_LOG_PARAMS(input, output, stride);
+    auto k = std::make_unique<CLReorgLayerKernel>();
     k->configure(compile_context, input, output, stride);
     _kernel = std::move(k);
 }
