@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2020 Arm Limited.
+ * Copyright (c) 2019-2020, 2023 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -240,7 +240,6 @@ public:
         {
             arm_compute::graph::Target::NEON,
             arm_compute::graph::Target::CL,
-            arm_compute::graph::Target::GC,
         };
 
         const std::set<arm_compute::DataType> supported_data_types
@@ -310,8 +309,6 @@ public:
  *
  * @param[in]  options       Options to consume
  * @param[out] common_params params structure to consume.
- *
- * @return consume_common_graph_parameters structure containing the common graph parameters
  */
 void consume_common_graph_parameters(CommonGraphValidateOptions &options, CommonParams &common_params)
 {
@@ -337,11 +334,11 @@ inline std::unique_ptr<graph::ITensorAccessor> get_accessor(const TensorParams &
 {
     if(!tensor.npy.empty())
     {
-        return arm_compute::support::cpp14::make_unique<arm_compute::graph_utils::NumPyBinLoader>(tensor.npy);
+        return std::make_unique<arm_compute::graph_utils::NumPyBinLoader>(tensor.npy);
     }
     else
     {
-        return arm_compute::support::cpp14::make_unique<arm_compute::graph_utils::RandomAccessor>(lower, upper, seed);
+        return std::make_unique<arm_compute::graph_utils::RandomAccessor>(lower, upper, seed);
     }
 }
 
@@ -446,8 +443,6 @@ public:
      * @param[in]  seed   seed for the randomization function
      * @param[in]  low    lower bound for random values
      * @param[in]  high   upper bound for random values
-     *
-     * @return None.
      */
     void fill_tensor(arm_compute::test::SimpleTensor<uint8_t> &tensor, std::random_device::result_type seed, uint8_t low, uint8_t high)
     {
@@ -474,8 +469,6 @@ public:
      * @param[in]  seed   seed for the randomization function
      * @param[in]  low    lower bound for random values
      * @param[in]  high   upper bound for random values
-     *
-     * @return None.
      */
     void fill_tensor(arm_compute::test::SimpleTensor<int32_t> &tensor, std::random_device::result_type seed, int32_t low, int32_t high)
     {
@@ -495,8 +488,6 @@ public:
      * @param[in]  seed   seed for the randomization function
      * @param[in]  low    lower bound for random values
      * @param[in]  high   upper bound for random values
-     *
-     * @return None.
      */
     void fill_tensor(arm_compute::test::SimpleTensor<float> &tensor, std::random_device::result_type seed, float low, float high)
     {
@@ -517,8 +508,6 @@ public:
      * @param[in]  seed   seed for the randomization function
      * @param[in]  low    lower bound for random values
      * @param[in]  high   upper bound for random values
-     *
-     * @return None.
      */
     void fill_tensor(arm_compute::test::SimpleTensor<half> &tensor, std::random_device::result_type seed, half low, half high)
     {
@@ -560,8 +549,6 @@ public:
      *
      * @param[in] tensor Tensor result of the actual operation passed into the Accessor.
      * @param[in] output Tensor result of the reference implementation.
-     *
-     * @return None.
      */
     void validate(ITensor &tensor, arm_compute::test::SimpleTensor<D> output)
     {
@@ -607,17 +594,17 @@ inline std::unique_ptr<graph::ITensorAccessor> get_verify_accessor(ExampleParams
     {
         case DataType::QASYMM8:
         {
-            return arm_compute::support::cpp14::make_unique<VerifyAccessorT<uint8_t>>(
+            return std::make_unique<VerifyAccessorT<uint8_t>>(
                        params);
         }
         case DataType::F16:
         {
-            return arm_compute::support::cpp14::make_unique<VerifyAccessorT<half>>(
+            return std::make_unique<VerifyAccessorT<half>>(
                        params);
         }
         case DataType::F32:
         {
-            return arm_compute::support::cpp14::make_unique<VerifyAccessorT<float>>(
+            return std::make_unique<VerifyAccessorT<float>>(
                        params);
         }
         default:
