@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2020 Arm Limited.
+ * Copyright (c) 2017-2023 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -22,6 +22,7 @@
  * SOFTWARE.
  */
 #include "tests/validation/Helpers.h"
+#include "tests/framework/Asserts.h"
 
 #include <algorithm>
 #include <cmath>
@@ -32,82 +33,6 @@ namespace test
 {
 namespace validation
 {
-void fill_mask_from_pattern(uint8_t *mask, int cols, int rows, MatrixPattern pattern)
-{
-    unsigned int                v = 0;
-    std::mt19937                gen(library->seed());
-    std::bernoulli_distribution dist(0.5);
-
-    for(int r = 0; r < rows; ++r)
-    {
-        for(int c = 0; c < cols; ++c, ++v)
-        {
-            uint8_t val = 0;
-
-            switch(pattern)
-            {
-                case MatrixPattern::BOX:
-                    val = 255;
-                    break;
-                case MatrixPattern::CROSS:
-                    val = ((r == (rows / 2)) || (c == (cols / 2))) ? 255 : 0;
-                    break;
-                case MatrixPattern::DISK:
-                    val = (((r - rows / 2.0f + 0.5f) * (r - rows / 2.0f + 0.5f)) / ((rows / 2.0f) * (rows / 2.0f)) + ((c - cols / 2.0f + 0.5f) * (c - cols / 2.0f + 0.5f)) / ((cols / 2.0f) *
-                            (cols / 2.0f))) <= 1.0f ? 255 : 0;
-                    break;
-                case MatrixPattern::OTHER:
-                    val = (dist(gen) ? 0 : 255);
-                    break;
-                default:
-                    return;
-            }
-
-            mask[v] = val;
-        }
-    }
-
-    if(pattern == MatrixPattern::OTHER)
-    {
-        std::uniform_int_distribution<uint8_t> distribution_u8(0, ((cols * rows) - 1));
-        mask[distribution_u8(gen)] = 255;
-    }
-}
-
-HarrisCornersParameters harris_corners_parameters()
-{
-    HarrisCornersParameters params;
-
-    std::mt19937                           gen(library->seed());
-    std::uniform_real_distribution<float>  threshold_dist(0.f, 0.001f);
-    std::uniform_real_distribution<float>  sensitivity(0.04f, 0.15f);
-    std::uniform_real_distribution<float>  euclidean_distance(0.f, 30.f);
-    std::uniform_int_distribution<uint8_t> int_dist(0, 255);
-
-    params.threshold             = threshold_dist(gen);
-    params.sensitivity           = sensitivity(gen);
-    params.min_dist              = euclidean_distance(gen);
-    params.constant_border_value = int_dist(gen);
-
-    return params;
-}
-
-CannyEdgeParameters canny_edge_parameters()
-{
-    CannyEdgeParameters params;
-
-    std::mt19937                           gen(library->seed());
-    std::uniform_int_distribution<uint8_t> int_dist(0, 255);
-    std::uniform_int_distribution<uint8_t> threshold_dist(2, 255);
-
-    params.constant_border_value = int_dist(gen);
-    params.upper_thresh          = threshold_dist(gen); // upper_threshold >= 2
-    threshold_dist               = std::uniform_int_distribution<uint8_t>(1, params.upper_thresh - 1);
-    params.lower_thresh          = threshold_dist(gen); // lower_threshold >= 1 && lower_threshold < upper_threshold
-
-    return params;
-}
-
 template <>
 SimpleTensor<float> convert_from_asymmetric(const SimpleTensor<uint8_t> &src)
 {
@@ -401,6 +326,153 @@ std::pair<int, int> get_symm_quantized_per_channel_bounds(const QuantizationInfo
     return std::pair<int, int> { min_bound, max_bound };
 }
 
+void add_padding_x(std::initializer_list<ITensor *> tensors, const DataLayout &data_layout, bool only_right_pad)
+{
+    if(data_layout == DataLayout::NHWC)
+    {
+        constexpr unsigned int lower = 1U;
+        constexpr unsigned int upper = 16U;
+
+        std::uniform_int_distribution<unsigned int> distribution(lower, upper);
+        size_t                                      seed_offset = 0;
+
+        for(ITensor *tensor : tensors)
+        {
+            ARM_COMPUTE_ERROR_ON(!tensor->info()->is_resizable());
+
+            std::mt19937 gen(library->seed() + seed_offset++);
+
+            const unsigned int right = distribution(gen);
+            const unsigned int left  = only_right_pad ? 0 : distribution(gen);
+
+            tensor->info()->extend_padding(PaddingSize(0U, right, 0U, left));
+        }
+    }
+}
+
+void add_padding_y(std::initializer_list<ITensor *> tensors, const DataLayout &data_layout)
+{
+    if(data_layout == DataLayout::NHWC)
+    {
+        constexpr unsigned int lower = 1U;
+        constexpr unsigned int upper = 4U;
+
+        std::uniform_int_distribution<unsigned int> distribution(lower, upper);
+        size_t                                      seed_offset = 0;
+
+        for(ITensor *tensor : tensors)
+        {
+            ARM_COMPUTE_ERROR_ON(!tensor->info()->is_resizable());
+
+            std::mt19937 gen(library->seed() + seed_offset++);
+
+            const unsigned int top    = distribution(gen);
+            const unsigned int bottom = distribution(gen);
+
+            tensor->info()->extend_padding(PaddingSize(top, 0U, bottom, 0U));
+        }
+    }
+}
+
+QuantizationInfo calculate_mat_mul_dst_q_info(const QuantizationInfo &a_q_info, const QuantizationInfo &b_q_info, int m, int n, int k, DataType data_type)
+{
+    ARM_COMPUTE_UNUSED(m, n);
+    QuantizationInfo c_q_info;
+
+    ARM_COMPUTE_ASSERT(data_type == DataType::QASYMM8 || data_type == DataType::QASYMM8_SIGNED);
+
+    const int32_t t_max = static_cast<int32_t>(data_type == DataType::QASYMM8 ? std::numeric_limits<uint8_t>::max() : std::numeric_limits<int8_t>::max());
+    const int32_t t_min = static_cast<int32_t>(data_type == DataType::QASYMM8 ? std::numeric_limits<uint8_t>::min() : std::numeric_limits<int8_t>::min());
+
+    /**  Quantization Setup of matrix multiplication
+     *
+     *  We have a matrix multiplication of the form C = A * B
+     *  where A is (M X K), B is (K x N) and C is therefore (M x N).
+     *
+     *  If we have some distributions statistics of A and B, i.e. mean and variance,
+     *  we can estimate the mean and variance of a single value in C matrix and
+     *  pick good scale and offset values for the output and have non-saturated tests.
+     *
+     *  Each element in the output matrix can be calculated as follows:
+     *      C_ij = sum_k(A_ik * B_kj)
+     *
+     *      All values are float above.
+     *
+     * Note: All possible A_ik, B_kj random variables are assumed mutually independent.
+     *
+     * Terminology:
+     *  E[X]: Mean of the random variable X (sometimes referred as mu_x)
+     *  var(X): Variance of the random variable X (someimes referred as sigma^2_x)
+     *  std(X): sqrt(var(X)), standard deviation of X
+     *
+     * 1) Calculate the mean:
+     *      E[C_ij] = sum_k( E[A_ik] * E[B_kj] ) = K * mean_a * mean_b
+     *
+     *      Since elements of A and B are uniformly distributed random variables, we have
+     *          mean_a = (max_a + min_a) / 2, mean_b = (max_b + min_b ) / 2
+     *          max_a and min_a can be calculated with the scale_a/b and offset_a/b
+     *              by replacing data type minimum and maximums in the equations
+     *
+     * 2) Calculate the variance:
+     *      var(C_ij) = sum_k( var(A_ik * B_kj) )
+     *                = sum_k ( E[A_ik^2 * B_kj^2] - E[A_ik]^2E[B_kj^2] )
+     *                = ...
+     *                = K * (var_a * var_b + var_a * mean^2_b + var_b * mean^2_a)
+     *
+     *      Similarly, due to uniform random variable properties, we have
+     *          var_a = (max_a - min_a)^2 / 12
+     *          var_b = (max_b - min_b)^2 / 12
+     *
+     *
+     * 3) Now, we have an idea of what would an average C_ij will like and how much deviation
+     *    is present around it. The exact distribution of C is not easy to come up with dependent on K.
+     *    But, as K increases, due to Central Limit Theorem, it'll look more like a bell shaped figure,
+     *    approaching normal distribution.
+     *
+     *    This is useful because, in normal distribution, we know that values +- 2 std_deviation around
+     *    the mean constitute 95% of the values. Therefore, setting a plausible range for us:
+     *      C_range = [C_min, C_max] = [mean_c - 2 * std_c, mean_c + 2 * std_c]
+     *
+     * 4)
+     *    If we map this [C_min, C_max] to [0, 255] or [-128, 127] depending on the signedness of the
+     *    data type, we can find a suitable scale and offset for the output. On average, it's expected
+     *    that 5% of the output values will saturate and 95% will remain in the range.
+     *
+     *    The equations to be solved for offset_c and scale_c are:
+     *          C_min = scale_c * (type_min - offset_c)
+     *          C_max = scale_c * (type_max - offset_c)
+     */
+
+    const int32_t a_offset = a_q_info.uniform().offset;
+    const float   a_scale  = a_q_info.uniform().scale;
+    const int32_t b_offset = b_q_info.uniform().offset;
+    const float   b_scale  = b_q_info.uniform().scale;
+
+    // Lhs/A stats
+    const float max_a  = (t_max - a_offset) * a_scale;
+    const float min_a  = (t_min - a_offset) * a_scale;
+    const float mean_a = (max_a + min_a) / 2;
+    const float var_a  = (max_a - min_a) * (max_a - min_a) / 12;
+
+    // Rhs/B stats
+    const float max_b  = (t_max - b_offset) * b_scale;
+    const float min_b  = (t_min - b_offset) * b_scale;
+    const float mean_b = (max_b + min_b) / 2;
+    const float var_b  = (max_b - min_b) * (max_b - min_b) / 12;
+
+    // Output stats
+    const float mean_out = k * mean_a * mean_b;
+    const float var_out  = k * (var_a * var_b + var_a * mean_b * mean_b + var_b * mean_a * mean_a);
+    const float std_out  = sqrt(var_out);
+
+    // Output quantization setup
+    const float   scale_out  = 4 * std_out / 255;
+    const int32_t offset_out = static_cast<int32_t>(t_min - (mean_out - 2.f * std_out) / scale_out);
+
+    c_q_info = QuantizationInfo(scale_out, offset_out);
+    return c_q_info;
+}
+
 template void get_tile(const SimpleTensor<float> &in, SimpleTensor<float> &roi, const Coordinates &coord);
 template void get_tile(const SimpleTensor<half> &in, SimpleTensor<half> &roi, const Coordinates &coord);
 template void get_tile(const SimpleTensor<int> &in, SimpleTensor<int> &roi, const Coordinates &coord);
@@ -413,6 +485,8 @@ template void transpose_matrix(const SimpleTensor<half> &in, SimpleTensor<half>
 template void transpose_matrix(const SimpleTensor<int> &in, SimpleTensor<int> &out);
 template void transpose_matrix(const SimpleTensor<short> &in, SimpleTensor<short> &out);
 template void transpose_matrix(const SimpleTensor<char> &in, SimpleTensor<char> &out);
+template void transpose_matrix(const SimpleTensor<int8_t> &in, SimpleTensor<int8_t> &out);
+template void transpose_matrix(const SimpleTensor<uint8_t> &in, SimpleTensor<uint8_t> &out);
 template void matrix_multiply(const SimpleTensor<float> &a, const SimpleTensor<float> &b, SimpleTensor<float> &out);
 template void matrix_multiply(const SimpleTensor<half> &a, const SimpleTensor<half> &b, SimpleTensor<half> &out);
 
